@@ -1,8 +1,11 @@
 package App::Notifier::Service;
-$App::Notifier::Service::VERSION = '0.0901';
+$App::Notifier::Service::VERSION = '0.0902';
 use 5.014;
 
-use Mojolicious::Lite -signatures;
+use strict;
+use warnings;
+
+use Mojolicious::Lite;
 use Plack::Builder;
 
 use File::Spec ();
@@ -155,7 +158,7 @@ notifying that an event (such as the finish of a task) occured.
 
 =head1 VERSION
 
-version 0.0901
+version 0.0902
 
 =head1 SYNOPSIS
 
